kernel
0.1.0
kernel_
init
Sections
Safety
In crate kernel
kernel
Function
kernel_init
pub(crate) unsafe fn kernel_init() ->
!
Early init code.

Safety
Only a single core must be active and running this function.
The init call in this function must appear in the correct order.